@@ -1,5 +1,5 @@
 <?php
-// $Id: module.textsanitizer.php,v 1.4.2.1 2005/08/20 01:20:32 nobunobu Exp $
+// $Id: module.textsanitizer.php,v 1.8 2006/07/27 00:17:17 onokazu Exp $
 //  ------------------------------------------------------------------------ //
 //                XOOPS - PHP Content Management System                      //
 //                    Copyright (c) 2000 XOOPS.org                           //
@@ -109,14 +109,14 @@ class MyTextSanitizer
         if (count($this->smileys) == 0) {
             if ($getsmiles = $db->query("SELECT * FROM ".$db->prefix("smiles"))){
                 while ($smiles = $db->fetchArray($getsmiles)) {
-                    $message =& str_replace($smiles['code'], '<img src="'.XOOPS_UPLOAD_URL.'/'.htmlspecialchars($smiles['smile_url']).'" alt="" />', $message);
+                    $message = str_replace($smiles['code'], '<img src="'.XOOPS_UPLOAD_URL.'/'.htmlspecialchars($smiles['smile_url']).'" alt="" />', $message);
                     array_push($this->smileys, $smiles);
                 }
             }
         }
         elseif (is_array($this->smileys)) {
             foreach ($this->smileys as $smile) {
-                $message =& str_replace($smile['code'], '<img src="'.XOOPS_UPLOAD_URL.'/'.htmlspecialchars($smile['smile_url']).'" alt="" />', $message);
+                $message = str_replace($smile['code'], '<img src="'.XOOPS_UPLOAD_URL.'/'.htmlspecialchars($smile['smile_url']).'" alt="" />', $message);
             }
         }
         return $message;
@@ -132,7 +132,8 @@ class MyTextSanitizer
     {
         $patterns = array("/(^|[^]_a-z0-9-=\"'\/])([a-z]+?):\/\/([^, \r\n\"\(\)'<>]+)/i", "/(^|[^]_a-z0-9-=\"'\/])www\.([a-z0-9\-]+)\.([^, \r\n\"\(\)'<>]+)/i", "/(^|[^]_a-z0-9-=\"'\/])ftp\.([a-z0-9\-]+)\.([^, \r\n\"\(\)'<>]+)/i", "/(^|[^]_a-z0-9-=\"'\/:\.])([a-z0-9\-_\.]+?)@([^, \r\n\"\(\)'<>\[\]]+)/i");
         $replacements = array("\\1<a href=\"\\2://\\3\" target=\"_blank\">\\2://\\3</a>", "\\1<a href=\"http://www.\\2.\\3\" target=\"_blank\">www.\\2.\\3</a>", "\\1<a href=\"ftp://ftp.\\2.\\3\" target=\"_blank\">ftp.\\2.\\3</a>", "\\1<a href=\"mailto:\\2@\\3\">\\2@\\3</a>");
-        return preg_replace($patterns, $replacements, $text);
+        $ret = preg_replace($patterns, $replacements, $text);
+        return $ret;
     }
 
     /**
@@ -145,6 +146,9 @@ class MyTextSanitizer
      **/
     function &xoopsCodeDecode(&$text, $allowimage = 1)
     {
+        $imgCallbackPattern = "/\[img( align=\w+)]([^\"\(\)\?\&'<>]*)\[\/img\]/sU";
+        $text = preg_replace_callback($imgCallbackPattern, array($this, '_filterImgUrl'), $text);
+
         $patterns = array();
         $replacements = array();
         // RMV: added new markup for intrasite url (allows easier site moves)
@@ -199,7 +203,39 @@ class MyTextSanitizer
         $replacements[] = "java script:";
         $patterns[] = "/about:/si";
         $replacements[] = "about :";
-        return preg_replace($patterns, $replacements, $text);
+        $ret = preg_replace($patterns, $replacements, $text);
+        return $ret;
+    }
+
+    /**
+     * Filters out invalid strings included in URL, if any
+     *
+     * @param   array  $matches
+     * @return  string
+     */
+    function _filterImgUrl($matches)
+    {
+        if ($this->checkUrlString($matches[2])) {
+            return $matches[0];
+        } else {
+            return "";
+        }
+    }
+
+    /**
+     * Checks if invalid strings are included in URL
+     *
+     * @param   string  $text
+     * @return  bool
+     */
+    function checkUrlString($text)
+    {
+        // Check control code
+        if (preg_match("/[\\0-\\31]/", $text)) {
+            return false;
+        }
+        // check black pattern(deprecated)
+        return !preg_match("/^(javascript|vbscript|about):/i", $text);
     }
 
     /**
@@ -211,7 +247,8 @@ class MyTextSanitizer
      */
     function &nl2Br($text)
     {
-        return preg_replace("/(\015\012)|(\015)|(\012)/","<br />",$text);
+        $ret = preg_replace("/(\015\012)|(\015)|(\012)/","<br />",$text);
+        return $ret;
     }
 
     /**
@@ -223,7 +260,7 @@ class MyTextSanitizer
     function &addSlashes($text)
     {
         if (!get_magic_quotes_gpc()) {
-            $text =& addslashes($text);
+            $text = addslashes($text);
         }
         return $text;
     }
@@ -237,7 +274,7 @@ class MyTextSanitizer
     function &stripSlashesGPC($text)
     {
         if (get_magic_quotes_gpc()) {
-            $text =& stripslashes($text);
+            $text = stripslashes($text);
         }
         return $text;
     }
@@ -252,7 +289,8 @@ class MyTextSanitizer
     function &htmlSpecialChars($text)
     {
         //return preg_replace("/&amp;/i", '&', htmlspecialchars($text, ENT_QUOTES));
-        return preg_replace(array("/&amp;/i", "/&nbsp;/i"), array('&', '&amp;nbsp;'), htmlspecialchars($text, ENT_QUOTES));
+        $ret = preg_replace(array("/&amp;/i", "/&nbsp;/i"), array('&', '&amp;nbsp;'), htmlspecialchars($text, ENT_QUOTES));
+        return $ret;
     }
 
     /**
@@ -283,7 +321,7 @@ class MyTextSanitizer
             // html not allowed
             $text =& $this->htmlSpecialChars($text);
         }
-        $text =& $this->codePreConv($text, $xcode); // Ryuji_edit(2003-11-18)
+        $text = $this->codePreConv($text, $xcode); // Ryuji_edit(2003-11-18)
         $text =& $this->makeClickable($text);
         if ($smiley != 0) {
             // process smiley
@@ -302,7 +340,7 @@ class MyTextSanitizer
         if ($br != 0) {
             $text =& $this->nl2Br($text);
         }
-        $text =& $this->codeConv($text, $xcode, $image);    // Ryuji_edit(2003-11-18)
+        $text = $this->codeConv($text, $xcode, $image);    // Ryuji_edit(2003-11-18)
         return $text;
     }
 
@@ -324,7 +362,7 @@ class MyTextSanitizer
             // html not allowed
             $text =& $this->htmlSpecialChars($text);
         }
-        $text =& $this->codePreConv($text, $xcode); // Ryuji_edit(2003-11-18)
+        $text = $this->codePreConv($text, $xcode); // Ryuji_edit(2003-11-18)
         $text =& $this->makeClickable($text);
         if ($smiley != 0) {
             // process smiley
@@ -343,7 +381,7 @@ class MyTextSanitizer
         if ($br != 0) {
             $text =& $this->nl2Br($text);
         }
-        $text =& $this->codeConv($text, $xcode, $image);    // Ryuji_edit(2003-11-18)
+        $text = $this->codeConv($text, $xcode, $image);    // Ryuji_edit(2003-11-18)
         return $text;
     }
 
@@ -511,7 +549,8 @@ class MyTextSanitizer
 
     function &makeTareaData4Show(&$text, $html=1, $smiley=1, $xcode=1)
     {
-        return $this->displayTarea($text, $html, $smiley, $xcode);
+        $ret = $this->displayTarea($text, $html, $smiley, $xcode);
+        return $ret;
     }
 
     function makeTareaData4Edit($text)
@@ -521,7 +560,8 @@ class MyTextSanitizer
 
     function &makeTareaData4Preview(&$text, $html=1, $smiley=1, $xcode=1)
     {
-        return $this->previewTarea($text, $html, $smiley, $xcode);
+        $ret = $this->previewTarea($text, $html, $smiley, $xcode);
+        return $ret;
     }
 
     function makeTareaData4PreviewInForm($text)
@@ -538,7 +578,8 @@ class MyTextSanitizer
 
     function &oopsStripSlashesGPC($text)
     {
-        return $this->stripSlashesGPC($text);
+        $ret = $this->stripSlashesGPC($text);
+        return $ret;
     }
 
     function &oopsStripSlashesRT($text)
@@ -551,17 +592,20 @@ class MyTextSanitizer
 
     function &oopsAddSlashes($text)
     {
-        return $this->addSlashes($text);
+        $ret = $this->addSlashes($text);
+        return $ret;
     }
 
     function &oopsHtmlSpecialChars($text)
     {
-        return $this->htmlSpecialChars($text);
+        $ret = $this->htmlSpecialChars($text);
+        return $ret;
     }
 
     function &oopsNl2Br($text)
     {
-        return $this->nl2br($text);
+        $ret = $this->nl2br($text);
+        return $ret;
     }
     /**#@-*/
 }
