@@ -1,5 +1,5 @@
 <?php
-// $Id: functions.php,v 1.6 2005/10/24 11:44:16 onokazu Exp $
+// $Id: functions.php,v 1.7 2006/05/01 02:37:26 onokazu Exp $
 //  ------------------------------------------------------------------------ //
 //                XOOPS - PHP Content Management System                      //
 //                    Copyright (c) 2000 XOOPS.org                           //
@@ -522,10 +522,12 @@ function &getMailer()
     if ( file_exists(XOOPS_ROOT_PATH."/language/".$xoopsConfig['language']."/xoopsmailerlocal.php") ) {
         include_once XOOPS_ROOT_PATH."/language/".$xoopsConfig['language']."/xoopsmailerlocal.php";
         if ( class_exists("XoopsMailerLocal") ) {
-            return new XoopsMailerLocal();
+            $ret =& new XoopsMailerLocal();
+            return $ret;
         }
     }
-    return new XoopsMailer();
+    $ret =& new XoopsMailer();
+    return $ret;
 }
 
 function &xoops_gethandler($name, $optional = false )
@@ -544,7 +546,11 @@ function &xoops_gethandler($name, $optional = false )
     if (!isset($handlers[$name]) && !$optional ) {
         trigger_error('Class <b>'.$class.'</b> does not exist<br />Handler Name: '.$name, E_USER_ERROR);
     }
-    return isset($handlers[$name]) ? $handlers[$name] : false;
+    $ret = false;
+    if (isset($handlers[$name])) {
+        $ret =& $handlers[$name];
+    }
+    return $ret;
 }
 
 function &xoops_getmodulehandler($name = null, $module_dir = null, $optional = false)
@@ -574,7 +580,11 @@ function &xoops_getmodulehandler($name = null, $module_dir = null, $optional = f
     if (!isset($handlers[$module_dir][$name]) && !$optional) {
         trigger_error('Handler does not exist<br />Module: '.$module_dir.'<br />Name: '.$name, E_USER_ERROR);
     }
-    return isset($handlers[$module_dir][$name]) ? $handlers[$module_dir][$name] : false;
+    $ret = false;
+    if (isset($handlers[$module_dir][$name])) {
+        $ret =& $handlers[$module_dir][$name];
+    }
+    return $ret;
 }
 
 function xoops_getrank($rank_id =0, $posts = 0)
