@@ -1,5 +1,5 @@
 <?php
-// $Id: main.php,v 1.5 2005/08/03 12:39:16 onokazu Exp $
+// $Id: main.php,v 1.6 2006/05/01 02:37:29 onokazu Exp $
 //  ------------------------------------------------------------------------ //
 //                XOOPS - PHP Content Management System                      //
 //                    Copyright (c) 2000 XOOPS.org                           //
@@ -360,7 +360,7 @@ if ( $op == "submit" ) {
         $criteria->setOrder($order);
         $criteria->setLimit($limit);
         $criteria->setStart($start);
-        $foundusers =& $member_handler->getUsers($criteria, true);
+        $foundusers = $member_handler->getUsers($criteria, true);
         $ucount = 0;
         foreach (array_keys($foundusers) as $j) {
             if ($ucount % 2 == 0) {
