@@ -1,5 +1,5 @@
 <?php
-// $Id: main.php,v 1.5 2005/08/03 12:40:00 onokazu Exp $
+// $Id: main.php,v 1.7 2006/05/01 02:37:30 onokazu Exp $
 //  ------------------------------------------------------------------------ //
 //                XOOPS - PHP Content Management System                      //
 //                    Copyright (c) 2000 XOOPS.org                           //
@@ -59,7 +59,7 @@ case "updateUser":
         $member_handler =& xoops_gethandler('member');
         $edituser =& $member_handler->getUser($uid);
         $myts =& MyTextSanitizer::getInstance();
-        if ($edituser->getVar('uname') != $username && $member_handler->getUserCount(new Criteria('uname', addslashes($username))) > 0) {
+        if ($edituser->getVar('uname', 'n') != $username && $member_handler->getUserCount(new Criteria('uname', addslashes($username))) > 0) {
             xoops_cp_header();
             echo 'User name '.htmlspecialchars($username).' already exists';
             xoops_cp_footer();
@@ -99,7 +99,7 @@ case "updateUser":
                     xoops_cp_footer();
                     exit();
                 }
-                $edituser->setVar("pass", md5($_POST['pass']));
+                $edituser->setVar("pass", md5($myts->stripSlashesGPC(trim($_POST['pass']))));
             }
             if (!$member_handler->insertUser($edituser)) {
                 xoops_cp_header();
@@ -264,7 +264,7 @@ case "addUser":
                     xoops_cp_footer();
                     exit();
                 }
-                $newuser->setVar("pass", md5($_POST['pass']));
+                $newuser->setVar("pass", md5($myts->stripSlashesGPC(trim($_POST['pass']))));
             }
             $newuser->setVar("timezone_offset", $_POST['timezone_offset']);
             $newuser->setVar("uorder", $_POST['uorder']);
